1 new commit in galaxy-central:
https://bitbucket.org/galaxy/galaxy-central/commits/62bd6fe0e9aa/
changeset: 62bd6fe0e9aa
user: inithello
date: 2013-03-15 20:11:04
summary: Also require and pass-through authentication for the 'pushkey' mercurial command when pushing changes to a tool shed repository.
affected #: 1 file
--
This is a commit notification from bitbucket.org. You are receiving
this because you have the service enabled, addressing the recipient of
this email.
1 new commit in galaxy-central:
https://bitbucket.org/galaxy/galaxy-central/commits/185a0ed00d8f/
changeset: 185a0ed00d8f
user: dan
date: 2013-03-13 20:31:06
summary: Comment out description for vcf to summary tree converter tool.
affected #: 1 file
diff -r bdd46627880ce13479c49c065ee118952ba8e2f2 -r 185a0ed00d8f245aa4ec161ba134df38edf19f70 lib/galaxy/datatypes/converters/vcf_to_summary_tree_converter.xml
--- a/lib/galaxy/datatypes/converters/vcf_to_summary_tree_converter.xml
+++ b/lib/galaxy/datatypes/converters/vcf_to_summary_tree_converter.xml
@@ -1,5 +1,5 @@
<tool id="CONVERTER_vcf_to_summary_tree_0" name="Convert VCF to Summary Tree" version="1.0.0" hidden="true">
- <description>__NOT_USED_CURRENTLY_FOR_CONVERTERS__</description>
+ <!-- <description>__NOT_USED_CURRENTLY_FOR_CONVERTERS__</description> --><command interpreter="python">vcf_to_summary_tree_converter.py $input1 $output1</command><inputs><page>
Repository URL: https://bitbucket.org/galaxy/galaxy-central/
--
This is a commit notification from bitbucket.org. You are receiving
this because you have the service enabled, addressing the recipient of
this email.
1 new commit in galaxy-central:
https://bitbucket.org/galaxy/galaxy-central/commits/bdd46627880c/
changeset: bdd46627880c
user: dan
date: 2013-03-13 20:12:55
summary: Handle Updating Data Managers when installed from Tool Shed.
affected #: 1 file
diff -r 188400f16e5f997f16c2a31db99da55c37909d00 -r bdd46627880ce13479c49c065ee118952ba8e2f2 lib/galaxy/webapps/galaxy/controllers/admin_toolshed.py
--- a/lib/galaxy/webapps/galaxy/controllers/admin_toolshed.py
+++ b/lib/galaxy/webapps/galaxy/controllers/admin_toolshed.py
@@ -1683,6 +1683,9 @@
shed_util.pull_repository( repo, repository_clone_url, latest_ctx_rev )
suc.update_repository( repo, latest_ctx_rev )
tool_shed = suc.clean_tool_shed_url( tool_shed_url )
+ # Remove old Data Manager entries
+ if repository.includes_data_managers:
+ shed_util.remove_from_data_manager( trans.app, repository )
# Update the repository metadata.
metadata_dict, invalid_file_tups = suc.generate_metadata_for_changeset_revision( app=trans.app,
repository=repository,
@@ -1715,6 +1718,11 @@
shed_tool_conf=shed_tool_conf,
tool_panel_dict=tool_panel_dict,
new_install=False )
+ # Add new Data Manager entries
+ if 'data_manager' in metadata_dict:
+ new_data_managers = shed_util.install_data_managers( trans.app, trans.app.config.shed_data_manager_config_file, metadata_dict,
+ repository.get_shed_config_dict( trans.app ), os.path.join( relative_install_dir, name ),
+ repository, repository_tools_tups )
# Create tool_dependency records if necessary.
if 'tool_dependencies' in metadata_dict:
tool_dependencies = shed_util.create_tool_dependency_objects( trans.app, repository, relative_install_dir, set_status=False )
Repository URL: https://bitbucket.org/galaxy/galaxy-central/
--
This is a commit notification from bitbucket.org. You are receiving
this because you have the service enabled, addressing the recipient of
this email.
1 new commit in galaxy-central:
https://bitbucket.org/galaxy/galaxy-central/commits/188400f16e5f/
changeset: 188400f16e5f
user: greg
date: 2013-03-13 19:52:42
summary: Fix the json import in the new Galaxy bioatar controller.
affected #: 1 file
diff -r 5a17ab5f5466eaf61e80d6efda90c394c601f4ad -r 188400f16e5f997f16c2a31db99da55c37909d00 lib/galaxy/webapps/galaxy/controllers/biostar.py
--- a/lib/galaxy/webapps/galaxy/controllers/biostar.py
+++ b/lib/galaxy/webapps/galaxy/controllers/biostar.py
@@ -5,7 +5,7 @@
from galaxy.web.base.controller import BaseUIController, url_for, error, web
import base64
-import json
+from galaxy.util import json
import hmac
# Biostar requires all keys to be present, so we start with a template
Repository URL: https://bitbucket.org/galaxy/galaxy-central/
diff -r 750222a21eff68b96069d853a4744d6e3682508c -r 62bd6fe0e9aa297b4448dfbcae32d27c8e313c38 lib/galaxy/webapps/tool_shed/framework/middleware/hg.py
--- a/lib/galaxy/webapps/tool_shed/framework/middleware/hg.py
+++ b/lib/galaxy/webapps/tool_shed/framework/middleware/hg.py
@@ -56,12 +56,12 @@
times_downloaded += 1
connection.execute( "update repository set times_downloaded = %d where user_id = %d and name = '%s'" % ( times_downloaded, user_id, name.lower() ) )
connection.close()
- if cmd == 'unbundle':
+ if cmd in [ 'unbundle', 'pushkey' ]:
# This is an hg push from the command line. When doing this, the following commands, in order,
# will be retrieved from environ (see the docs at http://mercurial.selenic.com/wiki/WireProtocol):
- # # If mercurial version >= '2.2.3': capabilities -> batch -> branchmap -> unbundle -> listkeys -> pushkey
+ # # If mercurial version >= '2.2.3': capabilities -> batch -> branchmap -> unbundle -> listkeys -> pushkey -> listkeys
#
# The mercurial API unbundle() ( i.e., hg push ) method ultimately requires authorization.
# We'll force password entry every time a change set is pushed.
#
# When a user executes hg commit, it is not guaranteed to succeed. Mercurial records your name
@@ -56,12 +56,12 @@
#
- # The mercurial API unbundle() ( i.e., hg push ) method ultimately requires authorization.
+ # The mercurial API unbundle() ( i.e., hg push ) and pushkey() methods ultimately require authorization.
# We'll force password entry every time a change set is pushed.
#
Repository URL: https://bitbucket.org/galaxy/galaxy-central/
--
This is a commit notification from bitbucket.org. You are receiving
this because you have the service enabled, addressing the recipient of
this email.